This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[commit] Zap obsolete code segments


FYI,

The attatched is a first pass at removing all those little OBSOLETE code segments.

committed,
Andrew
2003-01-02  Andrew Cagney  <ac131313@redhat.com>

	* valarith.c (value_binop): Delete obsolete code and comments.
	* configure.host: Ditto.
	* buildsym.h (make_blockvector): Ditto.
	* buildsym.c (make_blockvector): Ditto.
	* defs.h (enum language): Ditto.
	(chill_demangle): Ditto.
	* elfread.c (elf_symtab_read): Ditto.
	* dwarfread.c (CHILL_PRODUCER): Ditto.
	(set_cu_language): Ditto.
	(handle_producer): Ditto.
	* expprint.c (print_subexp): Ditto.
	* gdbtypes.c (chill_varying_type): Ditto.
	* gdbtypes.h (builtin_type_chill_bool): Ditto.
	(builtin_type_chill_char, builtin_type_chill_long): Ditto.
	(builtin_type_chill_ulong, builtin_type_chill_real): Ditto.
	(chill_varying_type): Ditto.
	* language.h (_LANG_chill): Ditto.
	* language.c (binop_result_type, integral_type): Ditto.
	(character_type, string_type, structured_type): Ditto.
	(lang_bool_type, binop_type_check): Ditto.
	* stabsread.h (os9k_stabs): Ditto.
	* stabsread.c (os9k_type_vector, dbx_lookup_type): Ditto.
	(define_symbol, read_type, read_struct_fields): Ditto.
	(read_array_type, read_enum_type, read_huge_number): Ditto.
	(read_range_type, start_stabs): Ditto.
	* symfile.c (init_filename_language_table): Ditto.
	(add_psymbol_with_dem_name_to_list): Ditto.
	* symtab.c (symbol_init_language_specific): Ditto.
	(symbol_init_demangled_name, symbol_demangled_name): Ditto.
	* symtab.h (struct general_symbol_info): Ditto.
	(SYMBOL_CHILL_DEMANGLED_NAME): Ditto.
	* typeprint.c (typedef_print): Ditto.
	* utils.c (fprintf_symbol_filtered): Ditto.
	* valops.c (value_cast, search_struct_field, value_slice): Delete
	obsolete code.
	(varying_to_slice): Delete function.
	* value.h (COERCE_VARYING_ARRAY): Delete obsolete macro contents.
	(varying_to_slice): Delete declaration.
	* MAINTAINERS: Update.

Index: MAINTAINERS
===================================================================
RCS file: /cvs/src/src/gdb/MAINTAINERS,v
retrieving revision 1.214
diff -u -r1.214 MAINTAINERS
--- MAINTAINERS	10 Dec 2002 21:19:03 -0000	1.214
+++ MAINTAINERS	2 Jan 2003 13:28:17 -0000
@@ -60,7 +60,7 @@
 	alpha		--target=alpha-elf ,-Werror
 			Maintenance only
 
-	arc		(--target=arc-elf OBSOLETE)
+	arc		Deleted.
 
 	arm		--target=arm-elf ,
 			Fernando Nasser		fnasser@redhat.com
@@ -77,9 +77,9 @@
 	d10v		--target=d10v-elf ,-Werror
 			Maintenance only
 
-	d30v		(--target=d30v-elf OBSOLETE)
+	d30v		Deleted.
 
-	fr30		(--target=fr30-elf OBSOLETE)
+	fr30		Deleted.
 
 	h8300		--target=h8300hms ,-Werror
 			Maintenance only
@@ -91,7 +91,7 @@
 	i386		--target=i386-elf ,-Werror
 			Mark Kettenis           kettenis@gnu.org
 
-	i960		(--target=i960-coff OBSOLETE)
+	i960		Deleted.
 
 	ia64		--target=ia64-linux-gnu ,-Werror
 			(--target=ia64-elf broken)
@@ -107,7 +107,7 @@
 	m68k		--target=m68k-elf ,-Werror
 			Maintenance only
 
-	m88k		(--target=m88k OBSOLETE)
+	m88k		Deleted.
 
 	mcore		--target=mcore-elf ,-Werror
 			Maintenance only
Index: Makefile.in
===================================================================
RCS file: /cvs/src/src/gdb/Makefile.in,v
retrieving revision 1.299
diff -u -r1.299 Makefile.in
--- Makefile.in	26 Dec 2002 09:36:41 -0000	1.299
+++ Makefile.in	2 Jan 2003 13:28:22 -0000
@@ -482,26 +482,6 @@
     fi; \
   fi`
 
-# OBSOLETE CHILLFLAGS = $(CFLAGS)
-# OBSOLETE CHILL = gcc
-# OBSOLETE CHILL_FOR_TARGET = ` \
-# OBSOLETE   if [ -f $${rootme}/../gcc/Makefile ] ; then \
-# OBSOLETE     echo $${rootme}/../gcc/xgcc -B$${rootme}/../gcc/ -L$${rootme}/../gcc/ch/runtime/; \
-# OBSOLETE   else \
-# OBSOLETE     if [ "$(host_canonical)" = "$(target_canonical)" ] ; then \
-# OBSOLETE       echo $(CC); \
-# OBSOLETE     else \
-# OBSOLETE       t='$(program_transform_name)'; echo gcc | sed -e '' $$t; \
-# OBSOLETE     fi; \
-# OBSOLETE   fi`
-# OBSOLETE CHILL_LIB = ` \
-# OBSOLETE   if [ -f $${rootme}/../gcc/ch/runtime/libchill.a ] ; then \
-# OBSOLETE     echo $${rootme}/../gcc/ch/runtime/chillrt0.o \
-# OBSOLETE       $${rootme}/../gcc/ch/runtime/libchill.a; \
-# OBSOLETE   else \
-# OBSOLETE       echo -lchill; \
-# OBSOLETE   fi`
-
 # The use of $$(x_FOR_TARGET) reduces the command line length by not
 # duplicating the lengthy definition.
 TARGET_FLAGS_TO_PASS = \
@@ -1360,11 +1340,6 @@
 # will remove them.
 MAKEOVERRIDES=
 
-## This is ugly, but I don't want GNU make to put these variables in
-## the environment.  Older makes will see this as a set of targets
-## with no dependencies and no actions.
-# OBSOLETE unexport CHILLFLAGS CHILL_LIB CHILL_FOR_TARGET :
-
 ALLDEPFILES = a68v-nat.c \
 	aix-thread.c \
 	alpha-nat.c alphabsd-nat.c \
@@ -1539,7 +1514,6 @@
 	$(alphabsd_tdep_h) $(nbsd_tdep_h)
 annotate.o: annotate.c $(defs_h) $(annotate_h) $(value_h) $(target_h) \
 	$(gdbtypes_h) $(breakpoint_h)
-# OBSOLETE arc-tdep.o: arc-tdep.c
 arch-utils.o: arch-utils.c $(defs_h) $(arch_utils_h) $(gdbcmd_h) \
 	$(inferior_h) $(symtab_h) $(frame_h) $(inferior_h) $(breakpoint_h) \
 	$(gdb_wait_h) $(gdbcore_h) $(gdbcmd_h) $(target_h) $(annotate_h) \
@@ -1593,10 +1567,6 @@
 c-valprint.o: c-valprint.c $(defs_h) $(gdb_string_h) $(symtab_h) \
 	$(gdbtypes_h) $(expression_h) $(value_h) $(valprint_h) $(language_h) \
 	$(c_lang_h) $(cp_abi_h)
-# OBSOLETE ch-exp.o: ch-exp.c
-# OBSOLETE ch-lang.o: ch-lang.c
-# OBSOLETE ch-typeprint.o: ch-typeprint.c
-# OBSOLETE ch-valprint.o: ch-valprint.c
 charset.o: charset.c $(defs_h) $(charset_h) $(gdbcmd_h) gdb_assert.h
 cli-out.o: cli-out.c $(defs_h) $(ui_out_h) $(cli_out_h) $(gdb_string_h) \
 	$(gdb_assert_h)
@@ -1636,13 +1606,11 @@
 	$(gdbtypes_h) $(gdbcore_h) $(gdbcmd_h) $(target_h) $(value_h) \
 	$(opcode_cris_h) $(arch_utils_h) $(regcache_h) $(symfile_h) \
 	$(solib_h) $(solib_svr4_h) $(gdb_string_h)
-# OBSOLETE cxux-nat.o: cxux-nat.c
 d10v-tdep.o: d10v-tdep.c $(defs_h) $(frame_h) $(symtab_h) $(gdbtypes_h) \
 	$(gdbcmd_h) $(gdbcore_h) $(gdb_string_h) $(value_h) $(inferior_h) \
 	$(dis_asm_h) $(symfile_h) $(objfiles_h) $(language_h) \
 	$(arch_utils_h) $(regcache_h) $(floatformat_h) $(gdb_sim_d10v_h) \
 	$(sim_regno_h)
-# OBSOLETE d30v-tdep.o: d30v-tdep.c
 dbug-rom.o: dbug-rom.c $(defs_h) $(gdbcore_h) $(target_h) $(monitor_h) \
 	$(serial_h) $(regcache_h) $(m68k_tdep_h)
 dbxread.o: dbxread.c $(defs_h) $(gdb_string_h) $(gdb_obstack_h) \
@@ -1663,7 +1631,6 @@
 	$(gdb_assert_h) $(gdb_string_h) $(gdbtypes_h)
 dpx2-nat.o: dpx2-nat.c $(defs_h) $(gdbcore_h) $(gdb_string_h)
 dsrec.o: dsrec.c $(defs_h) $(serial_h) $(srec_h)
-# OBSOLETE dstread.o: dstread.c
 dummy-frame.o: dummy-frame.c $(defs_h) $(dummy_frame_h) $(regcache_h) \
 	$(frame_h) $(inferior_h) $(gdb_assert_h)
 dve3900-rom.o: dve3900-rom.c $(defs_h) $(gdbcore_h) $(target_h) $(monitor_h) \
@@ -1714,7 +1681,6 @@
 fork-child.o: fork-child.c $(defs_h) $(gdb_string_h) $(frame_h) \
 	$(inferior_h) $(target_h) $(gdb_wait_h) $(gdb_vfork_h) $(gdbcore_h) \
 	$(terminal_h) $(gdbthread_h) $(command_h)
-# OBSOLETE fr30-tdep.o: fr30-tdep.c
 frame.o: frame.c $(defs_h) $(frame_h) $(target_h) $(value_h) $(inferior_h) \
 	$(regcache_h) $(gdb_assert_h) $(gdb_string_h) $(builtin_regs_h) \
 	$(gdb_obstack_h) $(dummy_frame_h) $(gdbcore_h) $(annotate_h) \
@@ -1787,7 +1753,6 @@
 	$(symtab_h) $(gdbcmd_h) $(command_h) $(arch_utils_h) $(regcache_h) \
 	$(doublest_h) $(value_h) $(gdb_assert_h) $(i386_tdep_h) \
 	$(i387_tdep_h)
-# OBSOLETE i386aix-nat.o: i386aix-nat.c
 i386b-nat.o: i386b-nat.c $(defs_h)
 i386bsd-nat.o: i386bsd-nat.c $(defs_h) $(inferior_h) $(regcache_h) \
 	$(gdb_assert_h) $(gregset_h) $(i386_tdep_h) $(i387_tdep_h)
@@ -1800,8 +1765,6 @@
 i386gnu-tdep.o: i386gnu-tdep.c $(defs_h) $(i386_tdep_h)
 i386ly-tdep.o: i386ly-tdep.c $(defs_h) $(gdbcore_h) $(inferior_h) \
 	$(regcache_h) $(target_h) $(i386_tdep_h)
-# OBSOLETE i386m3-nat.o: i386m3-nat.c
-# OBSOLETE i386mach-nat.o: i386mach-nat.c
 i386nbsd-tdep.o: i386nbsd-tdep.c $(defs_h) $(gdbtypes_h) $(gdbcore_h) \
 	$(regcache_h) $(arch_utils_h) $(i386_tdep_h) $(i387_tdep_h) \
 	$(nbsd_tdep_h) $(solib_svr4_h)
@@ -1815,7 +1778,6 @@
 i387-tdep.o: i387-tdep.c $(defs_h) $(frame_h) $(inferior_h) $(language_h) \
 	$(value_h) $(gdbcore_h) $(floatformat_h) $(regcache_h) \
 	$(gdb_assert_h) $(gdb_string_h) $(doublest_h) $(i386_tdep_h)
-# OBSOLETE i960-tdep.o: i960-tdep.c
 ia64-aix-nat.o: ia64-aix-nat.c $(defs_h) $(inferior_h) $(target_h) \
 	$(gdbcore_h) $(regcache_h) $(symtab_h) $(bfd_h) $(symfile_h) \
 	$(objfiles_h) $(gdb_stat_h)
@@ -1910,8 +1872,6 @@
 m68knbsd-nat.o: m68knbsd-nat.c $(defs_h) $(inferior_h) $(gdbcore_h) \
 	$(regcache_h)
 m68knbsd-tdep.o: m68knbsd-tdep.c $(defs_h) $(gdbtypes_h) $(regcache_h)
-# OBSOLETE m88k-nat.o: m88k-nat.c
-# OBSOLETE m88k-tdep.o: m88k-tdep.c
 macrocmd.o: macrocmd.c $(defs_h) $(macrotab_h) $(macroexp_h) $(macroscope_h) \
 	$(command_h) $(gdbcmd_h)
 macroexp.o: macroexp.c $(defs_h) $(gdb_obstack_h) $(bcache_h) $(macrotab_h) \
@@ -2002,7 +1962,6 @@
 	$(gdb_stabs_h) $(serial_h) $(ocd_h) $(regcache_h)
 op50-rom.o: op50-rom.c $(defs_h) $(gdbcore_h) $(target_h) $(monitor_h) \
 	$(serial_h)
-# OBSOLETE os9kread.o: os9kread.c
 osabi.o: osabi.c $(defs_h) $(gdb_string_h) $(osabi_h) $(elf_bfd_h)
 p-lang.o: p-lang.c $(defs_h) $(gdb_string_h) $(symtab_h) $(gdbtypes_h) \
 	$(expression_h) $(parser_defs_h) $(language_h) $(p_lang_h) \
@@ -2064,7 +2023,6 @@
 remote-array.o: remote-array.c $(defs_h) $(gdbcore_h) $(target_h) \
 	$(gdb_string_h) $(command_h) $(serial_h) $(monitor_h) \
 	$(remote_utils_h) $(inferior_h) $(version_h) $(regcache_h)
-# OBSOLETE remote-bug.o: remote-bug.c
 remote-e7000.o: remote-e7000.c $(defs_h) $(gdbcore_h) $(gdbarch_h) \
 	$(inferior_h) $(target_h) $(value_h) $(command_h) $(gdb_string_h) \
 	$(gdbcmd_h) $(serial_h) $(remote_utils_h) $(symfile_h) $(regcache_h)
@@ -2078,9 +2036,6 @@
 remote-mips.o: remote-mips.c $(defs_h) $(inferior_h) $(bfd_h) $(symfile_h) \
 	$(gdbcmd_h) $(gdbcore_h) $(serial_h) $(target_h) $(remote_utils_h) \
 	$(gdb_string_h) $(gdb_stat_h) $(regcache_h)
-# OBSOLETE remote-nindy.o: remote-nindy.c
-# OBSOLETE remote-nrom.o: remote-nrom.c
-# OBSOLETE remote-os9k.o: remote-os9k.c
 remote-rdi.o: remote-rdi.c $(defs_h) $(gdb_string_h) $(frame_h) \
 	$(inferior_h) $(bfd_h) $(symfile_h) $(target_h) $(gdbcmd_h) \
 	$(objfiles_h) $(gdb_stabs_h) $(gdbthread_h) $(gdbcore_h) \
@@ -2112,7 +2067,6 @@
 	$(symfile_h) $(regcache_h) $(gdb_string_h) $(vx_share_ptrace_h) \
 	$(vx_share_xdr_ptrace_h) $(vx_share_xdr_ld_h) $(vx_share_xdr_rdb_h) \
 	$(vx_share_dbgRpcLib_h)
-# OBSOLETE remote-vx960.o: remote-vx960.c
 remote-vxmips.o: remote-vxmips.c $(defs_h) $(vx_share_regPacket_h) \
 	$(frame_h) $(inferior_h) $(target_h) $(gdbcore_h) $(command_h) \
 	$(symtab_h) $(symfile_h) $(regcache_h) $(gdb_string_h) \
Index: NEWS
===================================================================
RCS file: /cvs/src/src/gdb/NEWS,v
retrieving revision 1.96
diff -u -r1.96 NEWS
--- NEWS	3 Dec 2002 19:32:10 -0000	1.96
+++ NEWS	2 Jan 2003 13:28:24 -0000
@@ -17,9 +17,29 @@
 Fix for gdb/702: a -var-assign that updates the value now shows up
                  in a subsequent -var-update.
 
+* OBSOLETE configurations and files
+
+Configurations that have been declared obsolete in this release have
+been commented out.  Unless there is activity to revive these
+configurations, the next release of GDB will have their sources
+permanently REMOVED.
+
 * REMOVED configurations and files
 
 V850EA ISA				
+Motorola Delta 88000 running Sys V		m88k-motorola-sysv  or  delta88
+IBM AIX PS/2					i[3456]86-*-aix
+i386 running Mach 3.0				i[3456]86-*-mach3*
+i386 running Mach				i[3456]86-*-mach*
+i386 running OSF/1				i[3456]86-*osf1mk*
+HP/Apollo 68k Family				m68*-apollo*-sysv*,
+						m68*-apollo*-bsd*,
+						m68*-hp-bsd*, m68*-hp-hpux*
+Argonaut Risc Chip (ARC)			arc-*-*
+Mitsubishi D30V					d30v-*-*
+Fujitsu FR30					fr30-*-elf*
+OS/9000						i[34]86-*-os9k
+I960 with MON960				i960-*-coff
 
 * MIPS $fp behavior changed
 
Index: buildsym.c
===================================================================
RCS file: /cvs/src/src/gdb/buildsym.c,v
retrieving revision 1.24
diff -u -r1.24 buildsym.c
--- buildsym.c	17 Dec 2002 00:39:07 -0000	1.24
+++ buildsym.c	2 Jan 2003 13:28:25 -0000
@@ -480,10 +480,6 @@
     }
 }
 
-/* OBSOLETE Note that this is only used in this file and in dstread.c, which */
-/* OBSOLETE should be fixed to not need direct access to this function.  When */
-/* OBSOLETE that is done, it can be made static again. */
-
 static struct blockvector *
 make_blockvector (struct objfile *objfile)
 {
Index: buildsym.h
===================================================================
RCS file: /cvs/src/src/gdb/buildsym.h,v
retrieving revision 1.7
diff -u -r1.7 buildsym.h
--- buildsym.h	18 Nov 2002 19:14:10 -0000	1.7
+++ buildsym.h	2 Jan 2003 13:28:25 -0000
@@ -276,12 +276,6 @@
 
 extern void free_pending_blocks (void);
 
-/* OBSOLETE FIXME: Note that this is used only in buildsym.c and dstread.c, */
-/* OBSOLETE which should be fixed to not need direct access to */
-/* OBSOLETE make_blockvector. */
-
-/* OBSOLETE extern struct blockvector *make_blockvector (struct objfile *objfile); */
-
 /* FIXME: Note that this is used only in buildsym.c and dstread.c,
    which should be fixed to not need direct access to
    record_pending_block. */
Index: configure.host
===================================================================
RCS file: /cvs/src/src/gdb/configure.host,v
retrieving revision 1.44
diff -u -r1.44 configure.host
--- configure.host	21 Aug 2002 00:57:42 -0000	1.44
+++ configure.host	2 Jan 2003 13:28:25 -0000
@@ -15,7 +15,6 @@
 hppa*)			gdb_host_cpu=pa ;;
 i[3456]86*)		gdb_host_cpu=i386 ;;
 m68*)			gdb_host_cpu=m68k ;;
-# OBSOLETE m88*)			gdb_host_cpu=m88k ;;
 mips*)			gdb_host_cpu=mips ;;
 powerpc*)		gdb_host_cpu=powerpc ;;
 sparcv9 | sparc64)	gdb_host_cpu=sparc ;;
@@ -54,7 +53,6 @@
 i[3456]86-sequent-bsd*)	gdb_host=symmetry ;;  # dynix
 i[3456]86-sequent-sysv4*) gdb_host=ptx4 ;;
 i[3456]86-sequent-sysv*) gdb_host=ptx ;;
-# OBSOLETE i[3456]86-*-aix*)	gdb_host=i386aix ;;
 i[3456]86-*-bsd*)	gdb_host=i386bsd ;;
 i[3456]86-*-dgux*)	gdb_host=i386dgux ;;
 i[3456]86-*-freebsd*)	gdb_host=fbsd ;;
@@ -65,11 +63,8 @@
 i[3456]86-*-msdosdjgpp*) gdb_host=go32 ;;
 i[3456]86-*-linux*)	gdb_host=linux ;;
 i[3456]86-*-lynxos*)	gdb_host=i386lynx ;;
-# OBSOLETE i[3456]86-*-mach3*)	gdb_host=i386m3 ;;
-# OBSOLETE i[3456]86-*-mach*)	gdb_host=i386mach ;;
 i[3456]86-*-gnu*)	gdb_host=i386gnu ;;
 i[3456]86-*-openbsd*)	gdb_host=obsd ;;
-# OBSOLETE i[3456]86-*-osf1mk*)	gdb_host=i386mk ;;
 i[3456]86-*-sco3.2v5*)	gdb_host=i386sco5 ;;
 i[3456]86-*-sco3.2v4*)	gdb_host=i386sco4 ;;
 i[3456]86-*-sco*)	gdb_host=i386sco ;;
@@ -91,12 +86,8 @@
 m680[01]0-sun-sunos3*)	gdb_host=sun2os3 ;;
 m680[01]0-sun-sunos4*)	gdb_host=sun2os4 ;;
 
-# OBSOLETE m68*-apollo*-sysv*)	gdb_host=apollo68v ;;
-# OBSOLETE m68*-apollo*-bsd*)	gdb_host=apollo68b ;;
 m68*-att-*)		gdb_host=3b1 ;;
 m68*-bull*-sysv*)	gdb_host=dpx2 ;;
-# OBSOLETE m68*-hp-bsd*)		gdb_host=hp300bsd ;;
-# OBSOLETE m68*-hp-hpux*)		gdb_host=hp300hpux ;;
 m68*-*-linux*)		gdb_host=linux ;;
 m68*-*-lynxos*)		gdb_host=m68klynx ;;
 m68*-*-netbsd*)		gdb_host=nbsdaout ;;
@@ -105,10 +96,6 @@
 m68*-sun-sunos3*)	gdb_host=sun3os3 ;;
 m68*-sun-sunos4*)	gdb_host=sun3os4 ;;
 m68*-sun-*)		gdb_host=sun3os4 ;;
-
-# OBSOLETE m88*-motorola-sysv4*)	gdb_host=delta88v4 ;;
-# OBSOLETE m88*-motorola-sysv*)	gdb_host=delta88 ;;
-# OBSOLETE m88*-*-*)		gdb_host=m88k ;;
 
 mips-dec-mach3*)	gdb_host=mipsm3 ;;
 mips-dec-*)		gdb_host=decstation ;;
Index: configure.tgt
===================================================================
RCS file: /cvs/src/src/gdb/configure.tgt,v
retrieving revision 1.88
diff -u -r1.88 configure.tgt
--- configure.tgt	24 Dec 2002 19:21:10 -0000	1.88
+++ configure.tgt	2 Jan 2003 13:28:25 -0000
@@ -19,7 +19,6 @@
 i[3456]86*)		gdb_target_cpu=i386 ;;
 m68hc11*|m6811*)	gdb_target_cpu=m68hc11 ;;
 m68*)			gdb_target_cpu=m68k ;;
-# OBSOLETE m88*)			gdb_target_cpu=m88k ;;
 mips*)			gdb_target_cpu=mips ;;
 powerpc*)		gdb_target_cpu=powerpc ;;
 sparc*)			gdb_target_cpu=sparc ;;
@@ -46,8 +45,6 @@
 alpha*-*-netbsd*)	gdb_target=nbsd ;;
 alpha*-*-*)		gdb_target=alpha ;;
 
-# OBSOLETE arc-*-*)		gdb_target=arc ;;
-
 arm*-wince-pe)		gdb_target=wince ;;
 arm*-*-linux*)		gdb_target=linux
 			build_gdbserver=yes
@@ -69,14 +66,11 @@
 cris*)                  gdb_target=cris ;;
 
 d10v-*-*)		gdb_target=d10v ;;
-# OBSOLETE d30v-*-*)		gdb_target=d30v ;;
 
 h8300-*-*)		gdb_target=h8300 ;;
 h8500-*-*)		gdb_target=h8500 ;;
 
 
-# OBSOLETE fr30-*-elf*)		gdb_target=fr30 ;;
-
 frv-*-*)		gdb_target=frv ;;
 
 hppa*-*-bsd*)		gdb_target=hppabsd ;;
@@ -91,11 +85,9 @@
 i[3456]86-sequent-sysv4*) gdb_target=ptx4 ;;
 i[3456]86-sequent-sysv*) gdb_target=ptx ;;
 i[3456]86-ncr-*)	gdb_target=ncr3000 ;;
-# OBSOLETE i[3456]86-*-aix*)	gdb_target=i386aix ;;
 i[3456]86-*-bsd*)	gdb_target=i386bsd ;;
 i[3456]86-*-netbsd*)	gdb_target=nbsd ;;
 i[3456]86-*-openbsd*)	gdb_target=obsd ;;
-# OBSOLETE i[3456]86-*-os9k)	gdb_target=i386os9k ;;
 i[3456]86-*-go32*)	gdb_target=i386aout ;;
 i[3456]86-*-msdosdjgpp*) gdb_target=go32 ;;
 i[3456]86-*-lynxos*)	gdb_target=i386lynx ;;
@@ -111,23 +103,13 @@
 			build_gdbserver=yes
 			;;
 i[3456]86-*-isc*)	gdb_target=i386v ;;
-# OBSOLETE i[3456]86-*-mach3*)	gdb_target=i386m3 ;;
 i[3456]86-*-gnu*)	gdb_target=i386gnu ;;
 i[3456]86-*-netware*)	gdb_target=i386nw
 		configdirs="${configdirs} nlm" ;;
-# OBSOLETE i[3456]86-*-osf1mk*)	gdb_target=i386mk ;;
 i[3456]86-*-cygwin*)	gdb_target=cygwin  ;;
 i[3456]86-*-vxworks*)	gdb_target=vxworks ;;
 i[3456]86-*-*)		gdb_target=embed ;;
 
-# OBSOLETE i960-*-bout*)		gdb_target=vxworks960 ;;
-# OBSOLETE i960-nindy-coff*)	gdb_target=nindy960 ;;
-# OBSOLETE i960-*-coff*)		gdb_target=mon960 ;;
-# OBSOLETE i960-nindy-elf*)	gdb_target=nindy960 ;;
-# OBSOLETE i960-*-elf*)		gdb_target=mon960 ;;
-# OBSOLETE i960-*-nindy*)		gdb_target=nindy960 ;;
-# OBSOLETE i960-*-vxworks*)	gdb_target=vxworks960 ;;
-
 ia64-*-aix*)		gdb_target=aix ;;
 ia64-*-linux*)		gdb_target=linux
 			build_gdbserver=yes
@@ -141,10 +123,7 @@
 m68000-*-sunos3*)	gdb_target=sun2os3 ;;
 m68000-*-sunos4*)	gdb_target=sun2os4 ;;
 
-# OBSOLETE m68*-apollo*-bsd*)	gdb_target=apollo68b ;;
 m68*-bull-sysv*)	gdb_target=dpx2 ;;
-# OBSOLETE m68*-hp-bsd*)		gdb_target=hp300bsd ;;
-# OBSOLETE m68*-hp-hpux*)		gdb_target=hp300hpux ;;
 m68*-att-*)		gdb_target=3b1 ;;
 m68*-cisco*-*)		gdb_target=cisco ;;
 m68*-ericsson-*)	gdb_target=es1800 ;;
@@ -165,10 +144,6 @@
 m68*-*-sysv4*)		gdb_target=m68kv4 ;;
 m68*-*-vxworks*)	gdb_target=vxworks68 ;;
 
-# OBSOLETE m88*-motorola-sysv4*)	gdb_target=delta88v4 ;;
-# OBSOLETE m88*-motorola-*)	gdb_target=delta88 ;;
-# OBSOLETE m88*-*-*)		gdb_target=m88k ;;
-
 mcore*-*-*)		gdb_target=mcore ;;
 mips64*-big-*)		gdb_target=bigmips64 ;;
 mips*-big-*)		gdb_target=bigmips ;;
@@ -277,9 +252,6 @@
 xstormy16-*-*)          gdb_target=xstormy16 ;;
 
 vax-*-*)		gdb_target=vax ;;
-
-# OBSOLETE fr30-*-*)		gdb_target=fr30
-# OBSOLETE 			;;
 
 v850*-*-*)		gdb_target=v850
 			case ${gdb_host} in
Index: defs.h
===================================================================
RCS file: /cvs/src/src/gdb/defs.h,v
retrieving revision 1.104
diff -u -r1.104 defs.h
--- defs.h	13 Dec 2002 17:55:49 -0000	1.104
+++ defs.h	2 Jan 2003 13:28:26 -0000
@@ -207,7 +207,6 @@
     language_cplus,		/* C++ */
     language_objc,		/* Objective-C */
     language_java,		/* Java */
-    /* OBSOLETE language_chill,	*/	/* Chill */
     language_fortran,		/* Fortran */
     language_m2,		/* Modula-2 */
     language_asm,		/* Assembly language */
@@ -297,10 +296,6 @@
 extern int inside_entry_file (CORE_ADDR addr);
 
 extern int inside_main_func (CORE_ADDR pc);
-
-/* OBSOLETE From ch-lang.c, for the moment. (FIXME) */
-
-/* OBSOLETE extern char *chill_demangle (const char *); */
 
 /* From utils.c */
 
Index: dwarfread.c
===================================================================
RCS file: /cvs/src/src/gdb/dwarfread.c,v
retrieving revision 1.17
diff -u -r1.17 dwarfread.c
--- dwarfread.c	17 Dec 2002 00:39:07 -0000	1.17
+++ dwarfread.c	2 Jan 2003 13:28:30 -0000
@@ -108,10 +108,6 @@
 #define LCC_PRODUCER "NCR C/C++"
 #endif
 
-/* OBSOLETE #ifndef CHILL_PRODUCER */
-/* OBSOLETE #define CHILL_PRODUCER "GNU Chill " */
-/* OBSOLETE #endif */
-
 /* Flags to target_to_host() that tell whether or not the data object is
    expected to be signed.  Used, for example, when fetching a signed
    integer in the target environment which is used as a signed integer
@@ -543,9 +539,6 @@
     case LANG_C_PLUS_PLUS:
       cu_language = language_cplus;
       break;
-      /* OBSOLETE case LANG_CHILL: */
-      /* OBSOLETE   cu_language = language_chill; */
-      /* OBSOLETE   break; */
     case LANG_MODULA2:
       cu_language = language_m2;
       break;
@@ -1760,7 +1753,6 @@
     {
       processing_gcc_compilation =
 	STREQN (producer, GPLUS_PRODUCER, strlen (GPLUS_PRODUCER));
-      /* OBSOLETE || STREQN (producer, CHILL_PRODUCER, strlen (CHILL_PRODUCER)); */
     }
 
   /* Select a demangling style if we can identify the producer and if
Index: elfread.c
===================================================================
RCS file: /cvs/src/src/gdb/elfread.c,v
retrieving revision 1.27
diff -u -r1.27 elfread.c
--- elfread.c	17 Dec 2002 00:39:07 -0000	1.27
+++ elfread.c	2 Jan 2003 13:28:31 -0000
@@ -346,10 +346,10 @@
 		    /* Looks like a compiler-generated label.  Skip
 		       it.  The assembler should be skipping these (to
 		       keep executables small), but apparently with
-		       gcc on the (OBSOLETE) delta m88k SVR4, it
-		       loses.  So to have us check too should be
-		       harmless (but I encourage people to fix this in
-		       the assembler instead of adding checks here).  */
+		       gcc on the (deleted) delta m88k SVR4, it loses.
+		       So to have us check too should be harmless (but
+		       I encourage people to fix this in the assembler
+		       instead of adding checks here).  */
 		    continue;
 		  else
 		    {
Index: expprint.c
===================================================================
RCS file: /cvs/src/src/gdb/expprint.c,v
retrieving revision 1.10
diff -u -r1.10 expprint.c
--- expprint.c	19 Nov 2002 03:36:44 -0000	1.10
+++ expprint.c	2 Jan 2003 13:28:35 -0000
@@ -267,8 +267,6 @@
 	}
       else
 	{
-	  /* OBSOLETE int is_chill = exp->language_defn->la_language == language_chill; */
-	  /* OBSOLETE fputs_filtered (is_chill ? " [" : " {", stream); */
 	  fputs_filtered (" {", stream);
 	  for (tem = 0; tem < nargs; tem++)
 	    {
@@ -278,7 +276,6 @@
 		}
 	      print_subexp (exp, pos, stream, PREC_ABOVE_COMMA);
 	    }
-	  /* OBSOLETE fputs_filtered (is_chill ? "]" : "}", stream); */
 	  fputs_filtered ("}", stream);
 	}
       return;
@@ -286,29 +283,15 @@
     case OP_LABELED:
       tem = longest_to_int (exp->elts[pc + 1].longconst);
       (*pos) += 3 + BYTES_TO_EXP_ELEM (tem + 1);
-
-#if 0
-      if (0 /* OBSOLETE exp->language_defn->la_language == language_chill */)
-	{ /* OBSOLETE */
-	  fputs_filtered (".", stream); /* OBSOLETE */
-	  fputs_filtered (&exp->elts[pc + 2].string, stream); /* OBSOLETE */
-	  fputs_filtered (exp->elts[*pos].opcode == OP_LABELED ? ", " /* OBSOLETE */
-			  : ": ", /* OBSOLETE */
-			  stream); /* OBSOLETE */
-	} /* OBSOLETE */
-      else /* OBSOLETE */
-#endif
-	{
-	  /* Gcc support both these syntaxes.  Unsure which is preferred.  */
+      /* Gcc support both these syntaxes.  Unsure which is preferred.  */
 #if 1
-	  fputs_filtered (&exp->elts[pc + 2].string, stream);
-	  fputs_filtered (": ", stream);
+      fputs_filtered (&exp->elts[pc + 2].string, stream);
+      fputs_filtered (": ", stream);
 #else
-	  fputs_filtered (".", stream);
-	  fputs_filtered (&exp->elts[pc + 2].string, stream);
-	  fputs_filtered ("=", stream);
+      fputs_filtered (".", stream);
+      fputs_filtered (&exp->elts[pc + 2].string, stream);
+      fputs_filtered ("=", stream);
 #endif
-	}
       print_subexp (exp, pos, stream, PREC_SUFFIX);
       return;
 
Index: gdbtypes.c
===================================================================
RCS file: /cvs/src/src/gdb/gdbtypes.c,v
retrieving revision 1.64
diff -u -r1.64 gdbtypes.c
--- gdbtypes.c	17 Dec 2002 00:39:07 -0000	1.64
+++ gdbtypes.c	2 Jan 2003 13:28:40 -0000
@@ -2003,24 +2003,6 @@
 	 || (TYPE_CODE (t) == TYPE_CODE_BOOL)));
 }
 
-/* (OBSOLETE) Chill (OBSOLETE) varying string and arrays are
-   represented as follows:
-
-   struct { int __var_length; ELEMENT_TYPE[MAX_SIZE] __var_data};
-
-   Return true if TYPE is such a (OBSOLETE) Chill (OBSOLETE) varying
-   type. */
-
-/* OBSOLETE int */
-/* OBSOLETE chill_varying_type (struct type *type) */
-/* OBSOLETE { */
-/* OBSOLETE   if (TYPE_CODE (type) != TYPE_CODE_STRUCT */
-/* OBSOLETE       || TYPE_NFIELDS (type) != 2 */
-/* OBSOLETE       || strcmp (TYPE_FIELD_NAME (type, 0), "__var_length") != 0) */
-/* OBSOLETE     return 0; */
-/* OBSOLETE   return 1; */
-/* OBSOLETE } */
-
 /* Check whether BASE is an ancestor or base class or DCLASS 
    Return 1 if so, and 0 if not.
    Note: callers may want to check for identity of the types before
Index: gdbtypes.h
===================================================================
RCS file: /cvs/src/src/gdb/gdbtypes.h,v
retrieving revision 1.39
diff -u -r1.39 gdbtypes.h
--- gdbtypes.h	11 Dec 2002 20:19:39 -0000	1.39
+++ gdbtypes.h	2 Jan 2003 13:28:41 -0000
@@ -101,14 +101,14 @@
     TYPE_CODE_RANGE,		/* Range (integers within spec'd bounds) */
 
     /* A string type which is like an array of character but prints
-       differently (at least for (OBSOLETE) CHILL (OBSOLETE)).  It
-       does not contain a length field as Pascal strings (for many
-       Pascals, anyway) do; if we want to deal with such strings, we
-       should use a new type code.  */
+       differently (at least for (the deleted) CHILL).  It does not
+       contain a length field as Pascal strings (for many Pascals,
+       anyway) do; if we want to deal with such strings, we should use
+       a new type code.  */
     TYPE_CODE_STRING,
 
     /* String of bits; like TYPE_CODE_SET but prints differently (at
-       least for (OBSOLETE) CHILL (OBSOLETE)).  */
+       least for (the deleted) CHILL).  */
     TYPE_CODE_BITSTRING,
 
     /* Unknown type.  The length field is valid if we were able to
@@ -1020,14 +1020,6 @@
 extern struct type *builtin_type_m2_real;
 extern struct type *builtin_type_m2_bool;
 
-/* OBSOLETE Chill types */
-
-/* OBSOLETE extern struct type *builtin_type_chill_bool; */
-/* OBSOLETE extern struct type *builtin_type_chill_char; */
-/* OBSOLETE extern struct type *builtin_type_chill_long; */
-/* OBSOLETE extern struct type *builtin_type_chill_ulong; */
-/* OBSOLETE extern struct type *builtin_type_chill_real; */
-
 /* Fortran (F77) types */
 
 extern struct type *builtin_type_f_character;
@@ -1134,8 +1126,6 @@
 extern struct type *create_string_type (struct type *, struct type *);
 
 extern struct type *create_set_type (struct type *, struct type *);
-
-/* OBSOLETE extern int chill_varying_type (struct type *); */
 
 extern struct type *lookup_unsigned_typename (char *);
 
Index: language.c
===================================================================
RCS file: /cvs/src/src/gdb/language.c,v
retrieving revision 1.29
diff -u -r1.29 language.c
--- language.c	12 Oct 2002 16:03:30 -0000	1.29
+++ language.c	2 Jan 2003 13:28:42 -0000
@@ -568,8 +568,6 @@
          not needed. */
       return l1 > l2 ? VALUE_TYPE (v1) : VALUE_TYPE (v2);
       break;
-      /* OBSOLETE case language_chill: */
-      /* OBSOLETE    error ("Missing Chill support in function binop_result_check.");  */	/*FIXME */
     }
   internal_error (__FILE__, __LINE__, "failed internal consistency check");
   return (struct type *) 0;	/* For lint */
@@ -793,8 +791,6 @@
     case language_m2:
     case language_pascal:
       return TYPE_CODE (type) != TYPE_CODE_INT ? 0 : 1;
-      /* OBSOLETE case language_chill: */
-      /* OBSOLETE   error ("Missing Chill support in function integral_type.");	*//*FIXME */
     default:
       error ("Language not supported.");
     }
@@ -823,7 +819,6 @@
   CHECK_TYPEDEF (type);
   switch (current_language->la_language)
     {
-      /* OBSOLETE case language_chill: */
     case language_m2:
     case language_pascal:
       return TYPE_CODE (type) != TYPE_CODE_CHAR ? 0 : 1;
@@ -846,7 +841,6 @@
   CHECK_TYPEDEF (type);
   switch (current_language->la_language)
     {
-      /* OBSOLETE case language_chill: */
     case language_m2:
     case language_pascal:
       return TYPE_CODE (type) != TYPE_CODE_STRING ? 0 : 1;
@@ -874,7 +868,7 @@
     case language_cplus:
     case language_objc:
       /* Might be more cleanly handled by having a
-         TYPE_CODE_INT_NOT_BOOL for (OBSOLETE) CHILL and such
+         TYPE_CODE_INT_NOT_BOOL for (the deleted) CHILL and such
          languages, or a TYPE_CODE_INT_OR_BOOL for C.  */
       if (TYPE_CODE (type) == TYPE_CODE_INT)
 	return 1;
@@ -922,8 +916,6 @@
       return (TYPE_CODE (type) == TYPE_CODE_STRUCT) ||
 	(TYPE_CODE (type) == TYPE_CODE_SET) ||
 	(TYPE_CODE (type) == TYPE_CODE_ARRAY);
-      /* OBSOLETE case language_chill: */
-      /* OBSOLETE     error ("Missing Chill support in function structured_type.");	*//*FIXME */
     default:
       return (0);
     }
@@ -937,10 +929,6 @@
   struct type *type;
   switch (current_language->la_language)
     {
-#if 0
-      /* OBSOLETE case language_chill: */
-      /* OBSOLETE    return builtin_type_chill_bool; */
-#endif
     case language_fortran:
       sym = lookup_symbol ("logical", NULL, VAR_NAMESPACE, NULL, NULL);
       if (sym)
@@ -1169,11 +1157,6 @@
 	       type_op_error ("Arguments to %s must be of integral type.",op);
 	    break;
 	 }
-#endif
-
-#ifdef _LANG_chill /* OBSOLETE */
-	 /* OBSOLETE case language_chill: */
-	 /* OBSOLETE   error ("Missing Chill support in function binop_type_check.");	*//*FIXME */
 #endif
 
 	}
Index: language.h
===================================================================
RCS file: /cvs/src/src/gdb/language.h,v
retrieving revision 1.14
diff -u -r1.14 language.h
--- language.h	12 Oct 2002 02:39:12 -0000	1.14
+++ language.h	2 Jan 2003 13:28:42 -0000
@@ -35,7 +35,6 @@
 /* #include "lang_def.h" */
 #define	_LANG_c
 #define	_LANG_m2
-/* OBSOLETE #define	_LANG_chill */
 #define  _LANG_fortran
 #define  _LANG_pascal
 
Index: stabsread.c
===================================================================
RCS file: /cvs/src/src/gdb/stabsread.c,v
retrieving revision 1.46
diff -u -r1.46 stabsread.c
--- stabsread.c	17 Dec 2002 00:39:08 -0000	1.46
+++ stabsread.c	2 Jan 2003 13:28:45 -0000
@@ -242,36 +242,6 @@
       *(pp) = next_symbol_text (objfile);	\
   } while (0)
 
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE /* FIXME: These probably should be our own types (like rs6000_builtin_type
-// OBSOLETE    has its own types) rather than builtin_type_*.  */
-// OBSOLETE static struct type **os9k_type_vector[] =
-// OBSOLETE {
-// OBSOLETE   0,
-// OBSOLETE   &builtin_type_int,
-// OBSOLETE   &builtin_type_char,
-// OBSOLETE   &builtin_type_long,
-// OBSOLETE   &builtin_type_short,
-// OBSOLETE   &builtin_type_unsigned_char,
-// OBSOLETE   &builtin_type_unsigned_short,
-// OBSOLETE   &builtin_type_unsigned_long,
-// OBSOLETE   &builtin_type_unsigned_int,
-// OBSOLETE   &builtin_type_float,
-// OBSOLETE   &builtin_type_double,
-// OBSOLETE   &builtin_type_void,
-// OBSOLETE   &builtin_type_long_double
-// OBSOLETE };
-// OBSOLETE
-// OBSOLETE static void os9k_init_type_vector (struct type **);
-// OBSOLETE 
-// OBSOLETE static void
-// OBSOLETE os9k_init_type_vector (struct type **tv)
-// OBSOLETE {
-// OBSOLETE   unsigned int i;
-// OBSOLETE   for (i = 0; i < sizeof (os9k_type_vector) / sizeof (struct type **); i++)
-// OBSOLETE     tv[i] = (os9k_type_vector[i] == 0 ? 0 : *(os9k_type_vector[i]));
-// OBSOLETE }
-#endif /* OBSOLETE OS9K */
 
 /* Look up a dbx type-number pair.  Return the address of the slot
    where the type for that number-pair is stored.
@@ -336,12 +306,6 @@
 		      (type_vector_length * sizeof (struct type *)));
 	  memset (&type_vector[old_len], 0,
 		  (type_vector_length - old_len) * sizeof (struct type *));
-
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE 	  if (os9k_stabs)
-// OBSOLETE 	    /* Deal with OS9000 fundamental types.  */
-// OBSOLETE 	    os9k_init_type_vector (type_vector);
-#endif /* OBSOLETE OS9K */
 	}
       return (&type_vector[index]);
     }
@@ -2037,11 +2001,6 @@
 	}
 #endif
       SYMBOL_NAMESPACE (sym) = VAR_NAMESPACE;
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE       if (os9k_stabs)
-// OBSOLETE 	add_symbol_to_list (sym, &global_symbols);
-// OBSOLETE       else
-#endif /* OBSOLETE OS9K */
 	add_symbol_to_list (sym, &local_symbols);
       break;
 
@@ -2575,24 +2534,6 @@
       break;
 
     case 'f':			/* Function returning another type */
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE       if (os9k_stabs && **pp == '(')
-// OBSOLETE 	{
-// OBSOLETE 	  /* Function prototype; parse it.
-// OBSOLETE 	     We must conditionalize this on os9k_stabs because otherwise
-// OBSOLETE 	     it could be confused with a Sun-style (1,3) typenumber
-// OBSOLETE 	     (I think).  */
-// OBSOLETE 	  struct type *t;
-// OBSOLETE 	  ++*pp;
-// OBSOLETE 	  while (**pp != ')')
-// OBSOLETE 	    {
-// OBSOLETE 	      t = read_type (pp, objfile);
-// OBSOLETE 	      if (**pp == ',')
-// OBSOLETE 		++ * pp;
-// OBSOLETE 	    }
-// OBSOLETE 	}
-#endif /* OBSOLETE OS9K */
-
       type1 = read_type (pp, objfile);
       type = make_function_type (type1, dbx_lookup_type (typenums));
       break;
@@ -2671,36 +2612,12 @@
       }
 
     case 'k':			/* Const qualifier on some type (Sun) */
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE       /* ezannoni 2002-07-16: This can be safely deleted, because 'c'
-// OBSOLETE 	 means complex type in AIX stabs, while it means const qualifier
-// OBSOLETE 	 in os9k stabs.  Obviously we were supporting only the os9k meaning.
-// OBSOLETE 	 We were erroring out if we were reading AIX stabs.  Right now the
-// OBSOLETE 	 erroring out will happen in the default clause of the switch.  */
-// OBSOLETE     case 'c':			/* Const qualifier on some type (OS9000) */
-// OBSOLETE       /* Because 'c' means other things to AIX and 'k' is perfectly good,
-// OBSOLETE          only accept 'c' in the os9k_stabs case.  */
-// OBSOLETE       if (type_descriptor == 'c' && !os9k_stabs)
-// OBSOLETE 	return error_type (pp, objfile);
-#endif /* OBSOLETE OS9K */
       type = read_type (pp, objfile);
       type = make_cv_type (1, TYPE_VOLATILE (type), type,
 			   dbx_lookup_type (typenums));
       break;
 
     case 'B':			/* Volatile qual on some type (Sun) */
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE       /* ezannoni 2002-07-16: This can be safely deleted, because 'i'
-// OBSOLETE 	 means imported type in AIX stabs, while it means volatile qualifier
-// OBSOLETE 	 in os9k stabs.  Obviously we were supporting only the os9k meaning.
-// OBSOLETE 	 We were erroring out if we were reading AIX stabs.  Right now the
-// OBSOLETE 	 erroring out will happen in the default clause of the switch.  */
-// OBSOLETE     case 'i':			/* Volatile qual on some type (OS9000) */
-// OBSOLETE       /* Because 'i' means other things to AIX and 'B' is perfectly good,
-// OBSOLETE          only accept 'i' in the os9k_stabs case.  */
-// OBSOLETE       if (type_descriptor == 'i' && !os9k_stabs)
-// OBSOLETE 	return error_type (pp, objfile);
-#endif /* OBSOLETE OS9K */
       type = read_type (pp, objfile);
       type = make_cv_type (TYPE_CONST (type), 1, type,
 			   dbx_lookup_type (typenums));
@@ -2807,12 +2724,6 @@
       break;
 
     case 'b':
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE       if (os9k_stabs)
-// OBSOLETE 	/* Const and volatile qualified type.  */
-// OBSOLETE 	type = read_type (pp, objfile);
-// OBSOLETE       else
-#endif /* OBSOLETE OS9K */
 	{
 	  /* Sun ACC builtin int type */
 	  type = read_sun_builtin_type (pp, typenums, objfile);
@@ -3853,10 +3764,6 @@
 
   while (**pp != ';' && **pp != '\0')
     {
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE       if (os9k_stabs && **pp == ',')
-// OBSOLETE 	break;
-#endif /* OBSOLETE OS9K */
       STABS_CONTINUE (pp, objfile);
       /* Get space to record the next field's data.  */
       new = (struct nextfield *) xmalloc (sizeof (struct nextfield));
@@ -3901,9 +3808,9 @@
     }
   if (p[0] == ':' && p[1] == ':')
     {
-      /* (OBSOLETE) chill (OBSOLETE) the list of fields: the last
-         entry (at the head) is a partially constructed entry which we
-         now scrub. */
+      /* (the deleted) chill the list of fields: the last entry (at
+         the head) is a partially constructed entry which we now
+         scrub. */
       fip->list = fip->list->next;
     }
   return 1;
@@ -4510,11 +4417,6 @@
      Fortran adjustable arrays use Adigits or Tdigits for lower or upper;
      for these, produce a type like float[][].  */
 
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE   if (os9k_stabs)
-// OBSOLETE     index_type = builtin_type_int;
-// OBSOLETE   else
-#endif /* OBSOLETE OS9K */
     {
       index_type = read_type (pp, objfile);
       if (**pp != ';')
@@ -4528,11 +4430,7 @@
       (*pp)++;
       adjustable = 1;
     }
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE   lower = read_huge_number (pp, os9k_stabs ? ',' : ';', &nbits);
-#else /* OBSOLETE OS9K */
   lower = read_huge_number (pp, ';', &nbits);
-#endif /* OBSOLETE OS9K */
 
   if (nbits != 0)
     return error_type (pp, objfile);
@@ -4593,18 +4491,6 @@
   osyms = *symlist;
   o_nsyms = osyms ? osyms->nsyms : 0;
 
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE   if (os9k_stabs)
-// OBSOLETE     {
-// OBSOLETE       /* Size.  Perhaps this does not have to be conditionalized on
-// OBSOLETE          os9k_stabs (assuming the name of an enum constant can't start
-// OBSOLETE          with a digit).  */
-// OBSOLETE       read_huge_number (pp, 0, &nbits);
-// OBSOLETE       if (nbits != 0)
-// OBSOLETE 	return error_type (pp, objfile);
-// OBSOLETE     }
-#endif /* OBSOLETE OS9K */
-
   /* The aix4 compiler emits an extra field before the enum members;
      my guess is it's a type of some sort.  Just ignore it.  */
   if (**pp == '-')
@@ -4842,12 +4728,7 @@
       p++;
     }
 
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE   if (os9k_stabs)
-// OBSOLETE     upper_limit = ULONG_MAX / radix;
-// OBSOLETE   else
-#endif /* OBSOLETE OS9K */
-    upper_limit = LONG_MAX / radix;
+  upper_limit = LONG_MAX / radix;
 
   while ((c = *p++) >= '0' && c < ('0' + radix))
     {
@@ -5043,12 +4924,6 @@
   else if (self_subrange && n2 == 0 && n3 == 127)
     return init_type (TYPE_CODE_INT, 1, 0, NULL, objfile);
 
-#if 0
-  /* OBSOLETE else if (current_symbol && SYMBOL_LANGUAGE (current_symbol) == language_chill */
-  /* OBSOLETE          && !self_subrange) */
-  /* OBSOLETE   goto handle_true_range; */
-#endif
-
   /* We used to do this only for subrange of self or subrange of int.  */
   else if (n2 == 0)
     {
@@ -5553,10 +5428,6 @@
 
   /* FIXME: If common_block_name is not already NULL, we should complain().  */
   common_block_name = NULL;
-
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE   os9k_stabs = 0;
-#endif /* OBSOLETE OS9K */
 }
 
 /* Call after end_symtab() */
Index: stabsread.h
===================================================================
RCS file: /cvs/src/src/gdb/stabsread.h,v
retrieving revision 1.10
diff -u -r1.10 stabsread.h
--- stabsread.h	17 Dec 2002 00:39:08 -0000	1.10
+++ stabsread.h	2 Jan 2003 13:28:45 -0000
@@ -151,10 +151,6 @@
 
 extern void finish_global_stabs (struct objfile *objfile);
 
-#if 0 /* OBSOLETE OS9K */
-// OBSOLETE EXTERN int os9k_stabs;
-#endif /* OBSOLETE OS9K */
-
 /* COFF files can have multiple .stab sections, if they are linked
    using --split-by-reloc.  This linked list is used to pass the
    information into the functions in dbxread.c.  */
Index: symfile.c
===================================================================
RCS file: /cvs/src/src/gdb/symfile.c,v
retrieving revision 1.75
diff -u -r1.75 symfile.c
--- symfile.c	9 Dec 2002 00:59:26 -0000	1.75
+++ symfile.c	2 Jan 2003 13:28:47 -0000
@@ -1966,9 +1966,6 @@
       add_filename_language (".c++", language_cplus);
       add_filename_language (".java", language_java);
       add_filename_language (".class", language_java);
-      /* OBSOLETE add_filename_language (".ch", language_chill); */
-      /* OBSOLETE add_filename_language (".c186", language_chill); */
-      /* OBSOLETE add_filename_language (".c286", language_chill); */
       add_filename_language (".m", language_objc);
       add_filename_language (".f", language_fortran);
       add_filename_language (".F", language_fortran);
@@ -2447,10 +2444,6 @@
       SYMBOL_CPLUS_DEMANGLED_NAME (&psymbol) =
 	bcache (buf, dem_namelength + 1, objfile->psymbol_cache);
       break;
-      /* OBSOLETE case language_chill: */
-      /* OBSOLETE   SYMBOL_CHILL_DEMANGLED_NAME (&psymbol) = */
-      /* OBSOLETE     bcache (buf, dem_namelength + 1, objfile->psymbol_cache); */
-
       /* FIXME What should be done for the default case? Ignoring for now. */
     }
 
Index: symtab.c
===================================================================
RCS file: /cvs/src/src/gdb/symtab.c,v
retrieving revision 1.83
diff -u -r1.83 symtab.c
--- symtab.c	23 Dec 2002 16:43:18 -0000	1.83
+++ symtab.c	2 Jan 2003 13:28:51 -0000
@@ -418,10 +418,6 @@
     {
       gsymbol->language_specific.objc_specific.demangled_name = NULL;
     }
-  /* OBSOLETE else if (SYMBOL_LANGUAGE (symbol) == language_chill) */
-  /* OBSOLETE   { */
-  /* OBSOLETE     SYMBOL_CHILL_DEMANGLED_NAME (symbol) = NULL; */
-  /* OBSOLETE   } */
   else
     {
       memset (&gsymbol->language_specific, 0,
@@ -483,26 +479,6 @@
           gsymbol->language_specific.cplus_specific.demangled_name = NULL;
         }
     }
-#if 0
-  /* OBSOLETE if (demangled == NULL */
-  /* OBSOLETE     && (gsymbol->language == language_chill */
-  /* OBSOLETE         || gsymbol->language == language_auto)) */
-  /* OBSOLETE   { */
-  /* OBSOLETE     demangled = */
-  /* OBSOLETE       chill_demangle (gsymbol->name); */
-  /* OBSOLETE     if (demangled != NULL) */
-  /* OBSOLETE       { */
-  /* OBSOLETE         gsymbol->language = language_chill; */
-  /* OBSOLETE         gsymbol->language_specific.chill_specific.demangled_name = */
-  /* OBSOLETE           obsavestring (demangled, strlen (demangled), obstack); */
-  /* OBSOLETE         xfree (demangled); */
-  /* OBSOLETE       } */
-  /* OBSOLETE     else */
-  /* OBSOLETE       { */
-  /* OBSOLETE         gsymbol->language_specific.chill_specific.demangled_name = NULL; */
-  /* OBSOLETE       } */
-  /* OBSOLETE   } */
-#endif
 }
 
 /* Return the demangled name for a symbol based on the language for
@@ -519,9 +495,6 @@
 
   else 
     return NULL;
-
-  /* OBSOLETE (SYMBOL_LANGUAGE (symbol) == language_chill */
-  /* OBSOLETE ? SYMBOL_CHILL_DEMANGLED_NAME (symbol) */
 }
 
 /* Initialize the structure fields to zero values.  */
Index: symtab.h
===================================================================
RCS file: /cvs/src/src/gdb/symtab.h,v
retrieving revision 1.52
diff -u -r1.52 symtab.h
--- symtab.h	25 Nov 2002 20:31:06 -0000	1.52
+++ symtab.h	2 Jan 2003 13:28:52 -0000
@@ -94,13 +94,6 @@
       char *demangled_name;
     }
     objc_specific;
-#if 0
-/* OBSOLETE struct chill_specific        *//* For Chill */
-    /* OBSOLETE   { */
-    /* OBSOLETE     char *demangled_name; */
-    /* OBSOLETE   } */
-    /* OBSOLETE chill_specific; */
-#endif
   }
   language_specific;
 
@@ -164,9 +157,6 @@
 #define SYMBOL_DEMANGLED_NAME(symbol) \
   (symbol_demangled_name (&(symbol)->ginfo))
 extern char *symbol_demangled_name (struct general_symbol_info *symbol);
-
-/* OBSOLETE #define SYMBOL_CHILL_DEMANGLED_NAME(symbol) */
-/* OBSOLETE (symbol)->ginfo.language_specific.chill_specific.demangled_name */
 
 #define SYMBOL_OBJC_DEMANGLED_NAME(symbol)				\
    (symbol)->ginfo.language_specific.objc_specific.demangled_name
Index: typeprint.c
===================================================================
RCS file: /cvs/src/src/gdb/typeprint.c,v
retrieving revision 1.12
diff -u -r1.12 typeprint.c
--- typeprint.c	1 Aug 2002 17:18:33 -0000	1.12
+++ typeprint.c	2 Jan 2003 13:28:52 -0000
@@ -88,17 +88,6 @@
       type_print (type, "", stream, 0);
       break;
 #endif
-#ifdef _LANG_chill /* OBSOLETE */
-      /* OBSOLETE case language_chill: */
-      /* OBSOLETE   fprintf_filtered (stream, "SYNMODE "); */
-      /* OBSOLETE   if (!TYPE_NAME (SYMBOL_TYPE (new)) || */
-      /* OBSOLETE       !STREQ (TYPE_NAME (SYMBOL_TYPE (new)), SYMBOL_NAME (new))) */
-      /* OBSOLETE     fprintf_filtered (stream, "%s = ", SYMBOL_SOURCE_NAME (new)); */
-      /* OBSOLETE   else */
-      /* OBSOLETE     fprintf_filtered (stream, "<builtin> = "); */
-      /* OBSOLETE   type_print (type, "", stream, 0); */
-      /* OBSOLETE   break; */
-#endif
     default:
       error ("Language not supported.");
     }
Index: utils.c
===================================================================
RCS file: /cvs/src/src/gdb/utils.c,v
retrieving revision 1.87
diff -u -r1.87 utils.c
--- utils.c	30 Nov 2002 16:33:55 -0000	1.87
+++ utils.c	2 Jan 2003 13:28:53 -0000
@@ -2313,11 +2313,6 @@
 	      /* Commented out until ObjC handling is enabled.  */
 	      /*demangled = objc_demangle (name);*/
 	      /*break;*/
-#if 0
-	      /* OBSOLETE case language_chill: */
-	      /* OBSOLETE   demangled = chill_demangle (name); */
-	      /* OBSOLETE   break; */
-#endif
 	    default:
 	      demangled = NULL;
 	      break;
Index: valarith.c
===================================================================
RCS file: /cvs/src/src/gdb/valarith.c,v
retrieving revision 1.16
diff -u -r1.16 valarith.c
--- valarith.c	1 Aug 2002 17:18:33 -0000	1.16
+++ valarith.c	2 Jan 2003 13:28:54 -0000
@@ -859,7 +859,7 @@
     /* Integral operations here.  */
     /* FIXME:  Also mixed integral/booleans, with result an integer. */
     /* FIXME: This implements ANSI C rules (also correct for C++).
-       What about FORTRAN and (OBSOLETE) chill ?  */
+       What about FORTRAN and (the deleted) chill ?  */
     {
       unsigned int promoted_len1 = TYPE_LENGTH (type1);
       unsigned int promoted_len2 = TYPE_LENGTH (type2);
@@ -946,12 +946,6 @@
 	    case BINOP_MOD:
 	      /* Knuth 1.2.4, integer only.  Note that unlike the C '%' op,
 	         v1 mod 0 has a defined value, v1. */
-	      /* OBSOLETE Chill specifies that v2 must be > 0, so check for that. */
-	      /* OBSOLETE if (current_language->la_language == language_chill */
-	      /* OBSOLETE     && value_as_long (arg2) <= 0) */
-	      /* OBSOLETE { */
-	      /* OBSOLETE   error ("Second operand of MOD must be greater than zero."); */
-	      /* OBSOLETE } */
 	      if (v2 == 0)
 		{
 		  v = v1;
@@ -1070,12 +1064,6 @@
 	    case BINOP_MOD:
 	      /* Knuth 1.2.4, integer only.  Note that unlike the C '%' op,
 	         X mod 0 has a defined value, X. */
-	      /* OBSOLETE Chill specifies that v2 must be > 0, so check for that. */
-	      /* OBSOLETE if (current_language->la_language == language_chill */
-	      /* OBSOLETE     && v2 <= 0) */
-	      /* OBSOLETE { */
-	      /* OBSOLETE   error ("Second operand of MOD must be greater than zero."); */
-	      /* OBSOLETE } */
 	      if (v2 == 0)
 		{
 		  v = v1;
@@ -1339,7 +1327,7 @@
   else if (TYPE_CODE (type) == TYPE_CODE_INT || TYPE_CODE (type) == TYPE_CODE_BOOL)
     {
       /* Perform integral promotion for ANSI C/C++.  FIXME: What about
-         FORTRAN and (OBSOLETE) chill ?  */
+         FORTRAN and (the deleted) chill ?  */
       if (TYPE_LENGTH (type) < TYPE_LENGTH (builtin_type_int))
 	result_type = builtin_type_int;
 
Index: valops.c
===================================================================
RCS file: /cvs/src/src/gdb/valops.c,v
retrieving revision 1.84
diff -u -r1.84 valops.c
--- valops.c	4 Dec 2002 00:05:53 -0000	1.84
+++ valops.c	2 Jan 2003 13:28:55 -0000
@@ -376,49 +376,6 @@
       VALUE_POINTED_TO_OFFSET (arg2) = 0;	/* pai: chk_val */
       return arg2;
     }
-  /* OBSOLETE else if (chill_varying_type (type)) */
-  /* OBSOLETE   { */
-  /* OBSOLETE     struct type *range1, *range2, *eltype1, *eltype2; */
-  /* OBSOLETE     struct value *val; */
-  /* OBSOLETE     int count1, count2; */
-  /* OBSOLETE     LONGEST low_bound, high_bound; */
-  /* OBSOLETE     char *valaddr, *valaddr_data; */
-  /* OBSOLETE     *//* For lint warning about eltype2 possibly uninitialized: */
-  /* OBSOLETE     eltype2 = NULL; */
-  /* OBSOLETE     if (code2 == TYPE_CODE_BITSTRING) */
-  /* OBSOLETE       error ("not implemented: converting bitstring to varying type"); */
-  /* OBSOLETE     if ((code2 != TYPE_CODE_ARRAY && code2 != TYPE_CODE_STRING) */
-  /* OBSOLETE         || (eltype1 = check_typedef (TYPE_TARGET_TYPE (TYPE_FIELD_TYPE (type, 1))), */
-  /* OBSOLETE       eltype2 = check_typedef (TYPE_TARGET_TYPE (type2)), */
-  /* OBSOLETE                                (TYPE_LENGTH (eltype1) != TYPE_LENGTH (eltype2) */
-  /* OBSOLETE     *//*|| TYPE_CODE (eltype1) != TYPE_CODE (eltype2) *//* ))) */
-  /* OBSOLETE      error ("Invalid conversion to varying type"); */
-  /* OBSOLETE     range1 = TYPE_FIELD_TYPE (TYPE_FIELD_TYPE (type, 1), 0); */
-  /* OBSOLETE     range2 = TYPE_FIELD_TYPE (type2, 0); */
-  /* OBSOLETE     if (get_discrete_bounds (range1, &low_bound, &high_bound) < 0) */
-  /* OBSOLETE       count1 = -1; */
-  /* OBSOLETE     else */
-  /* OBSOLETE       count1 = high_bound - low_bound + 1; */
-  /* OBSOLETE     if (get_discrete_bounds (range2, &low_bound, &high_bound) < 0) */
-  /* OBSOLETE       count1 = -1, count2 = 0;	*//* To force error before */
-  /* OBSOLETE     else */
-  /* OBSOLETE       count2 = high_bound - low_bound + 1; */
-  /* OBSOLETE     if (count2 > count1) */
-  /* OBSOLETE       error ("target varying type is too small"); */
-  /* OBSOLETE     val = allocate_value (type); */
-  /* OBSOLETE     valaddr = VALUE_CONTENTS_RAW (val); */
-  /* OBSOLETE     valaddr_data = valaddr + TYPE_FIELD_BITPOS (type, 1) / 8; */
-  /* OBSOLETE     *//* Set val's __var_length field to count2. */
-  /* OBSOLETE     store_signed_integer (valaddr, TYPE_LENGTH (TYPE_FIELD_TYPE (type, 0)), */
-  /* OBSOLETE 	    count2); */
-  /* OBSOLETE     *//* Set the __var_data field to count2 elements copied from arg2. */
-  /* OBSOLETE     memcpy (valaddr_data, VALUE_CONTENTS (arg2), */
-  /* OBSOLETE      count2 * TYPE_LENGTH (eltype2)); */
-  /* OBSOLETE     *//* Zero the rest of the __var_data field of val. */
-  /* OBSOLETE     memset (valaddr_data + count2 * TYPE_LENGTH (eltype2), '\0', */
-  /* OBSOLETE      (count1 - count2) * TYPE_LENGTH (eltype2)); */
-  /* OBSOLETE     return val; */
-  /* OBSOLETE   } */
   else if (VALUE_LVAL (arg2) == lval_memory)
     {
       return value_at_lazy (type, VALUE_ADDRESS (arg2) + VALUE_OFFSET (arg2),
@@ -2163,22 +2120,23 @@
 		/* Look for a match through the fields of an anonymous union,
 		   or anonymous struct.  C++ provides anonymous unions.
 
-		   In the GNU Chill (OBSOLETE) implementation of
-		   variant record types, each <alternative field> has
-		   an (anonymous) union type, each member of the union
-		   represents a <variant alternative>.  Each <variant
-		   alternative> is represented as a struct, with a
-		   member for each <variant field>.  */
+		   In the GNU Chill (now deleted from GDB)
+		   implementation of variant record types, each
+		   <alternative field> has an (anonymous) union type,
+		   each member of the union represents a <variant
+		   alternative>.  Each <variant alternative> is
+		   represented as a struct, with a member for each
+		   <variant field>.  */
 
 		struct value *v;
 		int new_offset = offset;
 
 		/* This is pretty gross.  In G++, the offset in an
 		   anonymous union is relative to the beginning of the
-		   enclosing struct.  In the GNU Chill (OBSOLETE)
-		   implementation of variant records, the bitpos is
-		   zero in an anonymous union field, so we have to add
-		   the offset of the union here. */
+		   enclosing struct.  In the GNU Chill (now deleted
+		   from GDB) implementation of variant records, the
+		   bitpos is zero in an anonymous union field, so we
+		   have to add the offset of the union here. */
 		if (TYPE_CODE (field_type) == TYPE_CODE_STRUCT
 		    || (TYPE_NFIELDS (field_type) > 0
 			&& TYPE_FIELD_BITPOS (field_type, 0) == 0))
@@ -3406,9 +3364,6 @@
     error ("slice from bad array or bitstring");
   if (lowbound < lowerbound || length < 0
       || lowbound + length - 1 > upperbound)
-    /* OBSOLETE Chill allows zero-length strings but not arrays. */
-    /* OBSOLETE || (current_language->la_language == language_chill */
-    /* OBSOLETE && length == 0 && TYPE_CODE (array_type) == TYPE_CODE_ARRAY)) */
     error ("slice out of range");
   /* FIXME-type-allocation: need a way to free this type when we are
      done with it.  */
@@ -3462,19 +3417,6 @@
       VALUE_OFFSET (slice) = VALUE_OFFSET (array) + offset;
     }
   return slice;
-}
-
-/* Assuming OBSOLETE chill_varying_type (VARRAY) is true, return an
-   equivalent value as a fixed-length array. */
-
-struct value *
-varying_to_slice (struct value *varray)
-{
-  struct type *vtype = check_typedef (VALUE_TYPE (varray));
-  LONGEST length = unpack_long (TYPE_FIELD_TYPE (vtype, 0),
-				VALUE_CONTENTS (varray)
-				+ TYPE_FIELD_BITPOS (vtype, 0) / 8);
-  return value_slice (value_primitive_field (varray, 0, 1, vtype), 0, length);
 }
 
 /* Create a value for a FORTRAN complex number.  Currently most of
Index: value.h
===================================================================
RCS file: /cvs/src/src/gdb/value.h,v
retrieving revision 1.37
diff -u -r1.37 value.h
--- value.h	14 Oct 2002 02:02:42 -0000	1.37
+++ value.h	2 Jan 2003 13:28:55 -0000
@@ -241,9 +241,9 @@
 #define COERCE_NUMBER(arg)  \
   do { COERCE_ARRAY(arg);  COERCE_ENUM(arg); } while (0)
 
-#define COERCE_VARYING_ARRAY(arg, real_arg_type)	\
-/* OBSOLETE { if (chill_varying_type (real_arg_type)) */  \
-/* OBSOLETE     arg = varying_to_slice (arg), real_arg_type = VALUE_TYPE (arg); } */ 
+/* NOTE: cagney/2002-12-17: This macro was handling a chill language
+   problem but that language has gone away.  */
+#define COERCE_VARYING_ARRAY(arg, real_arg_type)
 
 /* If ARG is an enum, convert it to an integer.  */
 

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: eval.c
===================================================================
RCS file: /cvs/src/src/gdb/eval.c,v
retrieving revision 1.25
diff -u -r1.25 eval.c
--- eval.c	29 Nov 2002 19:15:14 -0000	1.25
+++ eval.c	2 Jan 2003 13:28:31 -0000
@@ -186,7 +186,7 @@
     return NULL;
 }
 
 /* This function evaluates tuples (in (OBSOLETE) Chill) or
    brace-initializers (in C/C++) for structure types.  */
 
 static struct value *
@@ -326,10 +326,11 @@
 }
 
 /* Recursive helper function for setting elements of array tuples for
-   (OBSOLETE) Chill.  The target is ARRAY (which has bounds LOW_BOUND
-   to HIGH_BOUND); the element value is ELEMENT; EXP, POS and NOSIDE
-   are as usual.  Evaluates index expresions and sets the specified
-   element(s) of ARRAY to ELEMENT.  Returns last index value.  */
+   (the deleted) Chill.  The target is ARRAY (which has bounds
+   LOW_BOUND to HIGH_BOUND); the element value is ELEMENT; EXP, POS
+   and NOSIDE are as usual.  Evaluates index expresions and sets the
+   specified element(s) of ARRAY to ELEMENT.  Returns last index
+   value.  */
 
 static LONGEST
 init_array_element (struct value *array, struct value *element,
@@ -186,7 +186,7 @@
 }
 
-/* This function evaluates tuples (in (OBSOLETE) Chill) or
+/* This function evaluates tuples (in (the deleted) Chill) or
    brace-initializers (in C/C++) for structure types.  */
 
Index: expression.h
===================================================================
RCS file: /cvs/src/src/gdb/expression.h,v
retrieving revision 1.8
diff -u -r1.8 expression.h
--- expression.h	19 Nov 2002 03:23:40 -0000	1.8
+++ expression.h	2 Jan 2003 13:28:36 -0000
@@ -109,11 +109,11 @@
        the second operand with itself that many times. */
     BINOP_CONCAT,
 
     /* For (OBSOLETE) Chill (OBSOLETE) and Pascal. */
     BINOP_IN,			/* Returns 1 iff ARG1 IN ARG2. */
 
-    /* This is the "colon operator" used various places in (OBSOLETE)
-       Chill (OBSOLETE). */
+    /* This is the "colon operator" used various places in (the
+       deleted) Chill. */
     BINOP_RANGE,
 
     /* This must be the highest BINOP_ value, for expprint.c.  */
@@ -122,13 +122,13 @@
     /* Operates on three values computed by following subexpressions.  */
     TERNOP_COND,		/* ?: */
 
-    /* A sub-string/sub-array.  (OBSOLETE) Chill (OBSOLETE) syntax:
+    /* A sub-string/sub-array.  (the deleted) Chill syntax:
        OP1(OP2:OP3).  Return elements OP2 through OP3 of OP1.  */
     TERNOP_SLICE,
 
-    /* A sub-string/sub-array.  (OBSOLETE) Chill (OBSOLETE) syntax:
-       OP1(OP2 UP OP3).  Return OP3 elements of OP1, starting with
-       element OP2. */
+    /* A sub-string/sub-array.  (The deleted) Chill syntax: OP1(OP2 UP
+       OP3).  Return OP3 elements of OP1, starting with element
+       OP2. */
     TERNOP_SLICE_COUNT,
 
     /* Multidimensional subscript operator, such as Modula-2 x[a,b,...].
@@ -259,7 +259,7 @@
     UNOP_ODD,
     UNOP_TRUNC,
 
     /* (OBSOLETE) Chill (OBSOLETE) builtin functions. */
     UNOP_LOWER, UNOP_UPPER, UNOP_LENGTH, UNOP_CARD, UNOP_CHMAX, UNOP_CHMIN,
 
     OP_BOOL,			/* Modula-2 builtin BOOLEAN type */
@@ -296,14 +296,14 @@
     OP_SCOPE,
 
     /* Used to represent named structure field values in brace
-       initializers (or tuples as they are called in (OBSOLETE) Chill
-       (OBSOLETE)).
+       initializers (or tuples as they are called in (the deleted)
+       Chill).
 
-       The gcc C syntax is NAME:VALUE or .NAME=VALUE, the (OBSOLETE)
-       Chill (OBSOLETE) syntax is .NAME:VALUE.  Multiple labels (as in
-       the (OBSOLETE) Chill (OBSOLETE) syntax .NAME1,.NAME2:VALUE) is
+       The gcc C syntax is NAME:VALUE or .NAME=VALUE, the (the
+       deleted) Chill syntax is .NAME:VALUE.  Multiple labels (as in
+       the (the deleted) Chill syntax .NAME1,.NAME2:VALUE) is
        represented as if it were .NAME1:(.NAME2:VALUE) (though that is
-       not valid (OBSOLETE) Chill (OBSOLETE) syntax).
+       not valid (the deleted) Chill syntax).
 
        The NAME is represented as for STRUCTOP_STRUCT;  VALUE follows. */
     OP_LABELED,
@@ -109,11 +109,11 @@
     BINOP_CONCAT,
 
-    /* For (OBSOLETE) Chill (OBSOLETE) and Pascal. */
+    /* For (the deleted) Chill and Pascal. */
     BINOP_IN,			/* Returns 1 iff ARG1 IN ARG2. */
 
@@ -259,7 +259,7 @@
     UNOP_TRUNC,
 
-    /* (OBSOLETE) Chill (OBSOLETE) builtin functions. */
+    /* (The deleted) Chill builtin functions.  */
     UNOP_LOWER, UNOP_UPPER, UNOP_LENGTH, UNOP_CARD, UNOP_CHMAX, UNOP_CHMIN,
 